# Changelog

All notable changes to this project will be documented in this file. See [standard-version](https://github.com/conventional-changelog/standard-version) for commit guidelines.

## [1.2.0](https://github.com/jayanthkoushik/shiny-mdc/compare/v1.1.0...v1.2.0) (2023-04-12)


### Features

* use more organized tex folder structure ([4296148](https://github.com/jayanthkoushik/shiny-mdc/commit/4296148d049c41634f80e8aa9535a5710d7d7874))


### Bug Fixes

* fix handling of labels in figures and tables ([0a6fb66](https://github.com/jayanthkoushik/shiny-mdc/commit/0a6fb6669cbc763f22af11dca108a489df60a8d4))
* reset figure counter in appendices ([de0514b](https://github.com/jayanthkoushik/shiny-mdc/commit/de0514be47f1c50be1eb9a551ab82767a0b87fe1))

## [1.1.0](https://github.com/jayanthkoushik/shiny-mdc/compare/v1.0.1...v1.1.0) (2023-04-12)


### Features

* align author list in `authsetup` using fixed size boxes ([ebfa391](https://github.com/jayanthkoushik/shiny-mdc/commit/ebfa3914b635f8609f6c3651ea7455b5649f02e9))
* increase max figure/table width for spacious and basic templates ([773ec2c](https://github.com/jayanthkoushik/shiny-mdc/commit/773ec2c9ddb6843e8eaa3b38c8f1f2c4844db46c))


### Bug Fixes

* wrap figures with empty frames to improve positioning ([7828c0b](https://github.com/jayanthkoushik/shiny-mdc/commit/7828c0b53f09c13e75de34fbb63fd7803ca060c2))

### [1.0.1](https://github.com/jayanthkoushik/shiny-mdc/compare/v1.0.0...v1.0.1) (2023-04-12)


### Bug Fixes

* change resource symlinks to hard links ([0c4ee32](https://github.com/jayanthkoushik/shiny-mdc/commit/0c4ee3290f7171bf6565f3f016444ca4cd955d25))
* fix equal contrib footnote in iclr template ([e1e5292](https://github.com/jayanthkoushik/shiny-mdc/commit/e1e5292090ec644cfd50e2bcea1cb9444f8ae20f))
* make citation space in `citet` non-breaking ([fd1bc73](https://github.com/jayanthkoushik/shiny-mdc/commit/fd1bc73904b3b31cea7bfa1af1dca7913c0414f7))
* remove citation repetition from templates using author-year format ([008c19b](https://github.com/jayanthkoushik/shiny-mdc/commit/008c19b87ca6b252861d37097b81c7cb6bcb202d))
* rewrite template handling ([39b79f4](https://github.com/jayanthkoushik/shiny-mdc/commit/39b79f4c96f275a8b22d955b0d35da8ef9c17a6f))
